==> jc-1.4.0.tar.gz: java/rmi/server/UnicastRemoteObject.h <==
// public class java.rmi.server.UnicastRemoteObject

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 46051fa019dc720f java_rmi_server_RemoteObject
// @dep_class 1c165ce24effd6b java_rmi_server_RemoteServer
// @dep_class 719785c1fd5bba70 java_rmi_server_UnicastRemoteObject

// header file dependencies
// @dep_header java_rmi_server_RemoteServer

#include "java/rmi/server/RemoteServer.h"

#ifndef _JC_java_rmi_server_UnicastRemoteObject_H_
#define _JC_java_rmi_server_UnicastRemoteObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_server_RMIClientSocketFactory$object;
struct _jc_java_rmi_server_RMIServerSocketFactory$object;
struct _jc_java_rmi_server_RemoteRef$object;
struct _jc_java_rmi_server_RemoteStub$object;

// Typedefs
typedef struct _jc_java_rmi_server_UnicastRemoteObject$sub_refs	_jc_java_rmi_server_UnicastRemoteObject$sub_refs;
typedef struct _jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs	_jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs;
typedef struct _jc_java_rmi_server_UnicastRemoteObject$refs	_jc_java_rmi_server_UnicastRemoteObject$refs;
typedef struct _jc_java_rmi_server_UnicastRemoteObject$nonrefs	_jc_java_rmi_server_UnicastRemoteObject$nonrefs;
typedef struct _jc_java_rmi_server_UnicastRemoteObject$object	_jc_java_rmi_server_UnicastRemoteObject$object;

typedef struct _jc_java_rmi_server_UnicastRemoteObject$fields_struct	_jc_java_rmi_server_UnicastRemoteObject$fields_struct;
typedef const struct _jc_java_rmi_server_UnicastRemoteObject$vmethods	_jc_java_rmi_server_UnicastRemoteObject$vmethods;
typedef const struct _jc_java_rmi_server_UnicastRemoteObject$vtable	_jc_java_rmi_server_UnicastRemoteObject$vtable;
typedef const struct _jc_java_rmi_server_UnicastRemoteObject$vtype	_jc_java_rmi_server_UnicastRemoteObject$vtype;

// Class fields structure
struct _jc_java_rmi_server_UnicastRemoteObject$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_server_UnicastRemoteObject$fields_struct _jc_java_rmi_server_UnicastRemoteObject$class_fields;

// Constructors
extern void _jc_java_rmi_server_UnicastRemoteObject$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *);
extern void _jc_java_rmi_server_UnicastRemoteObject$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *, jint);
extern void _jc_java_rmi_server_UnicastRemoteObject$method$_init$d02fa2c463ee2b56(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *, jint, struct _jc_object *, struct _jc_object *);
extern void _jc_java_rmi_server_UnicastRemoteObject$method$_init$bebac18f06a4adf7(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_rmi_server_UnicastRemoteObject$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *);
extern void _jc_java_rmi_server_UnicastRemoteObject$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_UnicastRemoteObject$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_rmi_server_UnicastRemoteObject$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_rmi_server_RemoteStub$object *_jc_java_rmi_server_UnicastRemoteObject$method$exportObject$fdad8b8740ba7633(_jc_env *, struct _jc_object *);
extern struct _jc_object *_jc_java_rmi_server_UnicastRemoteObject$method$exportObject$5fba91be9530118e(_jc_env *, struct _jc_object *, jint);
extern struct _jc_object *_jc_java_rmi_server_UnicastRemoteObject$method$exportObject$c206556d218112d4(_jc_env *, struct _jc_object *, jint, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_java_rmi_server_UnicastRemoteObject$method$exportObject$9622b1d13f18174f(_jc_env *, struct _jc_object *, jint, struct _jc_object *);
extern jboolean _jc_java_rmi_server_UnicastRemoteObject$method$unexportObject$97b803bbd7912e4c(_jc_env *, struct _jc_object *, jboolean);

// Virtual methods structure
struct _jc_java_rmi_server_UnicastRemoteObject$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *);
};

// Vtable
struct _jc_java_rmi_server_UnicastRemoteObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteServer$vmethods	java_rmi_server_RemoteServer;
	_jc_java_rmi_server_UnicastRemoteObject$vmethods	java_rmi_server_UnicastRemoteObject;
};

// Vtype
struct _jc_java_rmi_server_UnicastRemoteObject$vtype {
	_jc_type			type;
	_jc_java_rmi_server_UnicastRemoteObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_UnicastRemoteObject$sub_refs {
	struct _jc_object	*csf;
	struct _jc_object	*ssf;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_UnicastRemoteObject$refs {
    _jc_java_rmi_server_UnicastRemoteObject$sub_refs	java_rmi_server_UnicastRemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_refs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs {
	jint	port;
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_UnicastRemoteObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_nonrefs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs	java_rmi_server_UnicastRemoteObject;
};

// Object instance structure
struct _jc_java_rmi_server_UnicastRemoteObject$object {
	_jc_java_rmi_server_UnicastRemoteObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_UnicastRemoteObject$vtype	*vtype;
	_jc_java_rmi_server_UnicastRemoteObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_UnicastRemoteObject$vtype _jc_java_rmi_server_UnicastRemoteObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_UnicastRemoteObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_UnicastRemoteObject$class_object;

#endif	/* _JC_java_rmi_server_UnicastRemoteObject_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/UnicastRemoteObject.h <==
// public class java.rmi.server.UnicastRemoteObject

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8c9f90d92f098cf3 java_rmi_server_RemoteObject
// @dep_class 1c165ce24effd6b java_rmi_server_RemoteServer
// @dep_class 719785c1fd5bba70 java_rmi_server_UnicastRemoteObject

// header file dependencies
// @dep_header java_rmi_server_RemoteServer

#include "java/rmi/server/RemoteServer.h"

#ifndef _JC_java_rmi_server_UnicastRemoteObject_H_
#define _JC_java_rmi_server_UnicastRemoteObject_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_rmi_Remote$object;
struct _jc_java_rmi_server_RMIClientSocketFactory$object;
struct _jc_java_rmi_server_RMIServerSocketFactory$object;
struct _jc_java_rmi_server_RemoteRef$object;
struct _jc_java_rmi_server_RemoteStub$object;

// Typedefs
typedef struct _jc_java_rmi_server_UnicastRemoteObject$sub_refs	_jc_java_rmi_server_UnicastRemoteObject$sub_refs;
typedef struct _jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs	_jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs;
typedef struct _jc_java_rmi_server_UnicastRemoteObject$refs	_jc_java_rmi_server_UnicastRemoteObject$refs;
typedef struct _jc_java_rmi_server_UnicastRemoteObject$nonrefs	_jc_java_rmi_server_UnicastRemoteObject$nonrefs;
typedef struct _jc_java_rmi_server_UnicastRemoteObject$object	_jc_java_rmi_server_UnicastRemoteObject$object;

typedef struct _jc_java_rmi_server_UnicastRemoteObject$fields_struct	_jc_java_rmi_server_UnicastRemoteObject$fields_struct;
typedef const struct _jc_java_rmi_server_UnicastRemoteObject$vmethods	_jc_java_rmi_server_UnicastRemoteObject$vmethods;
typedef const struct _jc_java_rmi_server_UnicastRemoteObject$vtable	_jc_java_rmi_server_UnicastRemoteObject$vtable;
typedef const struct _jc_java_rmi_server_UnicastRemoteObject$vtype	_jc_java_rmi_server_UnicastRemoteObject$vtype;

// Class fields structure
struct _jc_java_rmi_server_UnicastRemoteObject$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_server_UnicastRemoteObject$fields_struct _jc_java_rmi_server_UnicastRemoteObject$class_fields;

// Constructors
extern void _jc_java_rmi_server_UnicastRemoteObject$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_UnicastRemoteObject$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_UnicastRemoteObject$method$_init$d02fa2c463ee2b56(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_UnicastRemoteObject$method$_init$bebac18f06a4adf7(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_rmi_server_UnicastRemoteObject$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_UnicastRemoteObject$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_UnicastRemoteObject$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_rmi_server_UnicastRemoteObject$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern struct _jc_java_rmi_server_RemoteStub$object *_jc_java_rmi_server_UnicastRemoteObject$method$exportObject$fdad8b8740ba7633(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_server_UnicastRemoteObject$method$exportObject$5fba91be9530118e(_jc_env *, struct _jc_object *, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_server_UnicastRemoteObject$method$exportObject$c206556d218112d4(_jc_env *, struct _jc_object *, jint, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_rmi_server_UnicastRemoteObject$method$exportObject$9622b1d13f18174f(_jc_env *, struct _jc_object *, jint, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_rmi_server_UnicastRemoteObject$method$unexportObject$97b803bbd7912e4c(_jc_env *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_server_UnicastRemoteObject$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_rmi_server_UnicastRemoteObject$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_server_UnicastRemoteObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_RemoteObject$vmethods	java_rmi_server_RemoteObject;
	_jc_java_rmi_server_RemoteServer$vmethods	java_rmi_server_RemoteServer;
	_jc_java_rmi_server_UnicastRemoteObject$vmethods	java_rmi_server_UnicastRemoteObject;
};

// Vtype
struct _jc_java_rmi_server_UnicastRemoteObject$vtype {
	_jc_type			type;
	_jc_java_rmi_server_UnicastRemoteObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_UnicastRemoteObject$sub_refs {
	struct _jc_object	*csf;
	struct _jc_object	*ssf;
};

// Reference instance fields (object)
struct _jc_java_rmi_server_UnicastRemoteObject$refs {
    _jc_java_rmi_server_UnicastRemoteObject$sub_refs	java_rmi_server_UnicastRemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_refs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_RemoteObject$sub_refs	java_rmi_server_RemoteObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs {
	jint	port;
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_UnicastRemoteObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_RemoteObject$sub_nonrefs	java_rmi_server_RemoteObject;
    _jc_java_rmi_server_RemoteServer$sub_nonrefs	java_rmi_server_RemoteServer;
    _jc_java_rmi_server_UnicastRemoteObject$sub_nonrefs	java_rmi_server_UnicastRemoteObject;
};

// Object instance structure
struct _jc_java_rmi_server_UnicastRemoteObject$object {
	_jc_java_rmi_server_UnicastRemoteObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_UnicastRemoteObject$vtype	*vtype;
	_jc_java_rmi_server_UnicastRemoteObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_UnicastRemoteObject$vtype _jc_java_rmi_server_UnicastRemoteObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_UnicastRemoteObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_UnicastRemoteObject$class_object;

#endif	/* _JC_java_rmi_server_UnicastRemoteObject_H_ */
